Welcome to py-moneyed's documentation!
======================================

These are the docs for py-moneyed |release|. Check the :doc:`/history` for
significant changes.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   usage
   formatting
   contributing
   history


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
